@@ -5,6 +5,7 @@ import argparse
 import os
 import subprocess
 import socket
+from platform import uname
 def run(robot_class):
     """
     """
@@ -15,21 +16,20 @@ def run(robot_class):
         sys.exit()
 
     parser = argparse.ArgumentParser()
-    parser.add_argument("--action", help="deploy or run")
+    parser.add_argument("--action", help="deploy, update")
 
     parser.add_argument("--ip_addr", help="IP address of the server")
     args = parser.parse_args()
     action = args.action
     host = args.ip_addr
 
-    if action == "deploy":
+    if action is not None:
         if args.ip_addr == None:
             print("ERROR: enter ip address with --ip_addr IP_OF_ROBOT")
             sys.exit()
         else:
             deploy(host)
-    elif action == None:
-        pass
+
     
 
         
@@ -69,10 +69,11 @@ def deploy(h):
         if os.name == 'nt':
             try:
                 # Note: this line will show an error on *nix machines, can be safely ignored
+                
                 p = subprocess.Popen(['C:\Program Files\Git\\bin\\bash.exe','-c',cmd], stdout=subprocess.PIPE)
             except Exception as e:
                 print(e)
-                print("ERROR: Git Bash not installed")
+                print("do you have git bash installed?")
                 sys.exit()
         else:
             p = subprocess.Popen(["sh", "-c", cmd], stdout=subprocess.PIPE)
@@ -92,7 +93,6 @@ def deploy(h):
         with open(file_name, 'rb') as f:
             sbuf.put_bytes(f.read())
 
-        subprocess.Popen("rm " + file_name)
         print('File Sent')
 
     
\ No newline at end of file
